
## Summary
Replace pronouns with the nouns they represent.

## Installing
`pip install depronounize`

## Usage
```
from depronounize import replace_pronouns

print(replace_pronouns("I went to buy jam, but they were out of it."))
```
